# Pypotato library
Python API to control the following potentiostats:

* CHI760E from CH Instruments

More will be added soon.

Authors:

* Oliver Rodriguez*
* Michael Pence
* Joaquin Rodriguez-Lopez

University of Illinois at Urbana-Champaign.

Funded by JCESR.

# Installation
Clone the repository and from within the folder do:
```python
pip install pypotato
```

# Requirements
* numpy
* matplotlib
* scipy
* softpotato
